package Acme::CPANModules::NewDistributions::202001;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-02-06'; # DATE
our $DIST = 'Acme-CPANModules-NewDistributions-202001'; # DIST
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "Stats:\n\nNumber of new CPAN distributions this period: **105**\n\nNumber of authors releasing new CPAN distributions this period: **48**\n\nAuthors by number of new CPAN distributions this period:\n\n    +----+-----------+---------------+\n    | No | Author    | Distributions |\n    +----+-----------+---------------+\n    | 1  | PERLANCAR | 19            |\n    | 1  | SYBER     | 14            |\n    | 1  | VANHOESEL | 9             |\n    | 1  | TOBYINK   | 4             |\n    | 1  | DMOL      | 4             |\n    | 1  | LTM       | 3             |\n    | 1  | BOKUTIN   | 3             |\n    | 1  | CDRAKE    | 2             |\n    | 1  | MERKYS    | 2             |\n    | 1  | BLUEFEET  | 2             |\n    | 1  | BDFOY     | 2             |\n    | 1  | BOBK      | 2             |\n    | 1  | PROCH     | 2             |\n    | 1  | SRCHULO   | 2             |\n    | 1  | VRAG      | 2             |\n    | 1  | NIKOLAS   | 1             |\n    | 1  | DMUEY     | 1             |\n    | 1  | NQOUNET   | 1             |\n    | 1  | GENE      | 1             |\n    | 1  | HACKTOR   | 1             |\n    | 1  | HOUSTON   | 1             |\n    | 1  | VADIML    | 1             |\n    | 1  | GDT       | 1             |\n    | 1  | WBRASWELL | 1             |\n    | 1  | PIETRO    | 1             |\n    | 1  | AFAN      | 1             |\n    | 1  | YUSUKEBE  | 1             |\n    | 1  | HMBRAND   | 1             |\n    | 1  | YTURTLE   | 1             |\n    | 1  | SKIM      | 1             |\n    | 1  | DRAXIL    | 1             |\n    | 1  | ROBFARR   | 1             |\n    | 1  | JHTHORSEN | 1             |\n    | 1  | NHORNE    | 1             |\n    | 1  | PEVANS    | 1             |\n    | 1  | CXW       | 1             |\n    | 1  | BAYASHI   | 1             |\n    | 1  | RAJ       | 1             |\n    | 1  | SGRAY     | 1             |\n    | 1  | JLCOOPER  | 1             |\n    | 1  | PINGAN    | 1             |\n    | 1  | JV        | 1             |\n    | 1  | INGY      | 1             |\n    | 1  | MITHR     | 1             |\n    | 1  | JEFFOBER  | 1             |\n    | 1  | SISYPHUS  | 1             |\n    | 1  | GWILLIAMS | 1             |\n    | 1  | RVOSA     | 1             |\n    +----+-----------+---------------+\n\n",
  entries     => [
                   {
                     description => "Distribution Acme-CPANModules-OneAndTwoDecimalDigitsVersionTrap first released by PERLANCAR at 2020-01-02T11:37:54Z.",
                     module      => "Acme::CPANModules::OneAndTwoDecimalDigitsVersionTrap",
                     summary     => "Chronicles CPAN distributions which have been trapped by the one- and two decimal digits versioning scheme",
                   },
                   {
                     description => "Distribution Alien-boost-mini first released by SYBER at 2020-01-25T14:45:26Z.",
                     module      => "Alien::boost::mini",
                     summary     => "C++ Boost library (no perl interface).",
                   },
                   {
                     description => "Distribution Alien-cares first released by SYBER at 2020-01-25T15:30:14Z.",
                     module      => "Alien::cares",
                     summary     => "c-ares C library (alien, without perl-adapters).",
                   },
                   {
                     description => "Distribution Alien-catch first released by SYBER at 2020-01-24T15:25:30Z.",
                     module      => "Alien::catch",
                     summary     => "Catch test library http://catch-lib.net",
                   },
                   {
                     description => "Distribution Alien-libdwarf first released by DMOL at 2020-01-25T08:52:26Z.",
                     module      => "Alien::libdwarf",
                     summary     => "DWARF debugging information",
                   },
                   {
                     description => "Distribution Alien-libgeos first released by DMOL at 2020-01-25T09:57:02Z.",
                     module      => "Alien::libgeos",
                     summary     => "geos C++ library (alien, without perl-adapters).",
                   },
                   {
                     description => "Distribution Alien-libpanda first released by SYBER at 2020-01-24T16:14:02Z.",
                     module      => "Alien::libpanda",
                     summary     => "panda::lib C++ library (alien).",
                   },
                   {
                     description => "Distribution Alien-uv first released by SYBER at 2020-01-25T14:58:23Z.",
                     module      => "Alien::uv",
                     summary     => "libuv shared library (alien, without perl-adapters).",
                   },
                   {
                     description => "Distribution App-ProveRdeps first released by PERLANCAR at 2020-01-30T10:56:35Z.",
                     module      => "App::ProveRdeps",
                     summary     => "Prove all distributions depending on specified module(s)",
                   },
                   {
                     description => "Distribution App-Unicode-Block first released by SKIM at 2020-01-19T16:51:51Z.",
                     module      => "App::Unicode::Block",
                     summary     => "Distribution for unicode-block script.",
                   },
                   {
                     description => "Distribution App-geoip first released by HMBRAND at 2020-01-16T13:50:05Z.",
                     module      => "App::geoip",
                     summary     => "Show geological data based on hostname or IP address(es)",
                   },
                   {
                     description => "Distribution App-lcpan-CmdBundle-similar_authors first released by PERLANCAR at 2020-01-11T00:05:10Z.",
                     module      => "App::lcpan::CmdBundle::similar_authors",
                     summary     => "More lcpan subcommands related to finding similar authors",
                   },
                   {
                     description => "Distribution App-unbelievable first released by CXW at 2020-01-27T02:49:06Z.",
                     module      => "App::unbelievable",
                     summary     => "Yet another site generator (can you believe it?)",
                   },
                   {
                     description => "Distribution App-url first released by BDFOY at 2020-01-03T04:10:44Z.",
                     module      => "App::url",
                     summary     => "format a URL according to a sprintf-like template",
                   },
                   {
                     description => "Distribution AtteanX-Parser-JSONLD first released by GWILLIAMS at 2020-01-22T18:23:23Z.",
                     module      => "AtteanX::Parser::JSONLD",
                     summary     => "JSONLD Parser",
                   },
                   {
                     description => "Distribution Bencher-Scenario-strftimeq first released by PERLANCAR at 2020-01-26T00:05:03Z.",
                     module      => "Bencher::Scenario::strftimeq",
                     summary     => "Benchmark strftimeq() routines",
                   },
                   {
                     description => "Distribution Bencher-Scenarios-ModuleInstalledTiny first released by PERLANCAR at 2020-01-13T01:01:35Z.",
                     module      => "Bencher::Scenarios::ModuleInstalledTiny",
                     summary     => "Scenarios to benchmark Module::Installed::Tiny",
                   },
                   {
                     description => "Distribution BettingStrategy-MonteCarlo first released by NQOUNET at 2020-01-16T18:55:33Z.",
                     module      => "BettingStrategy::MonteCarlo",
                     summary     => "Monte Carlo method for gambling.",
                   },
                   {
                     description => "Distribution Bio-WGS2NCBI first released by RVOSA at 2020-01-23T15:54:29Z.",
                     module      => "Bio::WGS2NCBI",
                     summary     => "module to assist in submitting whole genome sequencing projects to NCBI",
                   },
                   {
                     description => "Distribution CGI-Application-Plugin-OpenTracing first released by VANHOESEL at 2020-01-16T13:57:56Z.",
                     module      => "CGI::Application::Plugin::OpenTracing",
                     summary     => "Use OpenTracing in CGI Applications",
                   },
                   {
                     description => "Distribution Calendar-Dates-UnitedNations-InternationalDays first released by PERLANCAR at 2020-01-01T11:35:05Z.",
                     module      => "Calendar::Dates::UnitedNations::InternationalDays",
                     summary     => "United Nations' International Days",
                   },
                   {
                     description => "Distribution Catalyst-Authentication-Credential-RedmineCookie first released by BOKUTIN at 2020-01-09T06:00:28Z.",
                     module      => "Catalyst::Authentication::Credential::RedmineCookie",
                     summary     => "Decode the redmine cookie _redmine_session",
                   },
                   {
                     description => "Distribution Catalyst-Authentication-RedmineCookie first released by BOKUTIN at 2020-01-17T07:22:36Z.",
                     module      => "Catalyst::Authentication::RedmineCookie",
                     summary     => "Decode the redmine cookie _redmine_session",
                   },
                   {
                     description => "Distribution Chart-Colors first released by CDRAKE at 2020-01-20T10:56:51Z.",
                     module      => "Chart::Colors",
                     summary     => "Perl extension to return an endless stream of new distinct RGB colours codes (good for coloring any number of chart lines)",
                   },
                   {
                     description => "Distribution Config-Registry first released by BLUEFEET at 2020-01-19T15:54:32Z.",
                     module      => "Config::Registry",
                     summary     => "Settings bundler.",
                   },
                   {
                     description => "Distribution Crypto-NanoRPC first released by HACKTOR at 2020-01-16T15:17:14Z.",
                     module      => "Crypto::NanoRPC",
                     summary     => "Perl module for interacting with Nano node",
                   },
                   {
                     description => "Distribution Data-Validate-Chemistry first released by MERKYS at 2020-01-29T14:38:32Z.",
                     module      => "Data::Validate::Chemistry",
                     summary     => "Validate common chemical identifiers",
                   },
                   {
                     description => "Distribution Date-strftimeq first released by PERLANCAR at 2020-01-19T01:57:48Z.",
                     module      => "Date::strftimeq",
                     summary     => "POSIX::strftime() with support for embedded perl code in %(...)q",
                   },
                   {
                     description => "Distribution DateTime-Format-Strftimeq first released by PERLANCAR at 2020-01-12T00:05:08Z.",
                     module      => "DateTime::Format::Strftimeq",
                     summary     => "Format DateTime object using DateTimeX::strftimeq",
                   },
                   {
                     description => "Distribution DateTimeX-strftimeq first released by PERLANCAR at 2020-01-05T00:05:58Z.",
                     module      => "DateTimeX::strftimeq",
                     summary     => "POSIX::strftime() with support for embedded perl code in %(...)q",
                   },
                   {
                     description => "Distribution Dist-Zilla-Plugin-Test-ProveDeps first released by PERLANCAR at 2020-01-29T09:03:54Z.",
                     module      => "Dist::Zilla::Plugin::Test::ProveDeps",
                     summary     => "Add release test to run 'prove' on dependent distributions",
                   },
                   {
                     description => "Distribution Dist-Zilla-Plugin-Test-ProveRdeps first released by PERLANCAR at 2020-01-30T11:45:24Z.",
                     module      => "Dist::Zilla::Plugin::Test::ProveRdeps",
                     summary     => "Add release test to run 'prove' on distributions that depend on us",
                   },
                   {
                     description => "Distribution Duadua first released by BAYASHI at 2020-01-31T05:07:25Z.",
                     module      => "Duadua",
                     summary     => "Detect User-Agent",
                   },
                   {
                     description => "Distribution Eircode first released by DRAXIL at 2020-01-20T11:11:18Z.",
                     module      => "Eircode",
                     summary     => "Validation and utilities for Eircodes / Irish postcodes",
                   },
                   {
                     description => "Distribution FTN-Crypt first released by PIETRO at 2020-01-15T20:49:51Z.",
                     module      => "FTN::Crypt",
                     summary     => "Encryption of the FTN messages.",
                   },
                   {
                     description => "Distribution File-BackupCopy first released by SGRAY at 2020-01-20T07:48:10Z.",
                     module      => "File::BackupCopy",
                     summary     => "create a backup copy of the file.",
                   },
                   {
                     description => "Distribution Font-Fontconfig first released by VANHOESEL at 2020-01-20T16:38:30Z.",
                     module      => "Font::Fontconfig",
                     summary     => "An Object Oriented interface to fontconfig",
                   },
                   {
                     description => "Distribution Font-Selector first released by VANHOESEL at 2020-01-21T08:20:21Z.",
                     module      => "Font::Selector",
                     summary     => "select the right font for rendering",
                   },
                   {
                     description => "Distribution Geo-Coder-DAMS first released by BOKUTIN at 2020-01-04T19:00:11Z.",
                     module      => "Geo::Coder::DAMS",
                     summary     => "Perl bindings for Japanese Geocoder DAMS",
                   },
                   {
                     description => "Distribution HarfBuzz-Shaper first released by JV at 2020-01-25T20:50:26Z.",
                     module      => "HarfBuzz::Shaper",
                     summary     => "Use HarfBuzz for text shaping",
                   },
                   {
                     description => "Distribution Huawei-Info-Ipaddr first released by PINGAN at 2020-01-08T15:01:58Z.",
                     module      => "Huawei::Info::Ipaddr",
                     summary     => undef,
                   },
                   {
                     description => "Distribution IO-EPP first released by VADIML at 2020-01-12T12:01:15Z.",
                     module      => "IO::EPP",
                     summary     => "Object and procedure interface of the client-side for work with EPP API of registries and some resellers",
                   },
                   {
                     description => "Distribution IP-Decimal first released by LTM at 2020-01-21T07:46:48Z.",
                     module      => "IP::Decimal",
                     summary     => "Convert IP to Decimal and Decimal to IP",
                   },
                   {
                     description => "Distribution JS-AA first released by LTM at 2020-01-24T00:59:33Z.",
                     module      => "JS::AA",
                     summary     => "Encode and Decode AA",
                   },
                   {
                     description => "Distribution JS-JJ first released by LTM at 2020-01-30T02:22:54Z.",
                     module      => "JS::JJ",
                     summary     => "Encode and Decode JJ",
                   },
                   {
                     description => "Distribution Lingua-FR-Numbers-Ordinate first released by NHORNE at 2020-01-03T03:04:16Z.",
                     module      => "Lingua::FR::Numbers::Ordinate",
                     summary     => "go from cardinal number (3) to ordinal (\"3e\")",
                   },
                   {
                     description => "Distribution List-Uniqnum first released by SISYPHUS at 2020-01-27T11:35:40Z.",
                     module      => "List::Uniqnum",
                     summary     => "a rendition of List::Util::uniqnum minus the bugs.",
                   },
                   {
                     description => "Distribution Loctools-Net first released by AFAN at 2020-01-15T21:38:52Z.",
                     module      => "Loctools::Net",
                     summary     => "Shared network-related modules",
                   },
                   {
                     description => "Distribution MLPerl first released by WBRASWELL at 2020-01-02T05:38:40Z.",
                     module      => "MLPerl",
                     summary     => "Machine Learning Algorithms & Applications in Perl",
                   },
                   {
                     description => "Distribution Math-StdDev first released by CDRAKE at 2020-01-20T09:50:44Z.",
                     module      => "Math::StdDev",
                     summary     => "Pure-perl mean and variance computation supporting running/online calculation (Welford's algorithm)",
                   },
                   {
                     description => "Distribution Mojo-DB-Connector first released by SRCHULO at 2020-01-26T01:25:31Z.",
                     module      => "Mojo::DB::Connector",
                     summary     => "Create and cache DB connections using common connection info",
                   },
                   {
                     description => "Distribution Mojo-DB-Results-Role-MoreMethods first released by SRCHULO at 2020-01-05T23:22:29Z.",
                     module      => "Mojo::DB::Results::Role::MoreMethods",
                     summary     => "More methods for DB Results, like Mojo::Pg::Results and Mojo::mysql::Results",
                   },
                   {
                     description => "Distribution Mojolicious-Plugin-Iconify first released by GDT at 2020-01-04T15:00:45Z.",
                     module      => "Mojolicious::Plugin::Iconify",
                     summary     => "Iconify helpers.",
                   },
                   {
                     description => "Distribution Mojolicious-Plugin-ServerType first released by JLCOOPER at 2020-01-13T13:12:40Z.",
                     module      => "Mojolicious::Plugin::ServerType",
                     summary     => "A Mojolicious Plugin that provides a helper that identifies the server type",
                   },
                   {
                     description => "Distribution Mojolicious-Plugin-Systemd first released by JHTHORSEN at 2020-01-09T00:02:48Z.",
                     module      => "Mojolicious::Plugin::Systemd",
                     summary     => "Configure your app from within systemd service file",
                   },
                   {
                     description => "Distribution MooX-Pression first released by TOBYINK at 2020-01-16T00:50:32Z.",
                     module      => "MooX::Pression",
                     summary     => "express yourself through moo",
                   },
                   {
                     description => "Distribution MooseX-Function-Parameters first released by ROBFARR at 2020-01-03T19:49:47Z.",
                     module      => "MooseX::Function::Parameters",
                     summary     => undef,
                   },
                   {
                     description => "Distribution Net-MyIP first released by RAJ at 2020-01-24T10:48:45Z.",
                     module      => "Net::MyIP",
                     summary     => "Get ip address from https://api.myip.com/",
                   },
                   {
                     description => "Distribution Net-Prometheus-Pushgateway first released by VRAG at 2020-01-17T15:03:05Z.",
                     module      => "Net::Prometheus::Pushgateway",
                     summary     => "client module for pushing metrics to prometheus exporter (pushgateway, prometheus aggregation gateway)",
                   },
                   {
                     description => "Distribution Net-PublicSuffixList first released by BDFOY at 2020-01-08T03:56:52Z.",
                     module      => "Net::PublicSuffixList",
                     summary     => "The Mozilla Public Suffix List",
                   },
                   {
                     description => "Distribution Net-SockAddr first released by SYBER at 2020-01-22T16:15:12Z.",
                     module      => "Net::SockAddr",
                     summary     => "Socket address OO-wrapper with Perl and C++ interface.",
                   },
                   {
                     description => "Distribution Net-SyslogNg first released by VRAG at 2020-01-10T09:59:11Z.",
                     module      => "Net::SyslogNg",
                     summary     => "client module for writing to syslog server (rfc5424)",
                   },
                   {
                     description => "Distribution Object-Adhoc first released by TOBYINK at 2020-01-24T17:12:36Z.",
                     module      => "Object::Adhoc",
                     summary     => "make objects without the hassle of defining a class first",
                   },
                   {
                     description => "Distribution Object-Depot first released by BLUEFEET at 2020-01-20T20:33:21Z.",
                     module      => "Object::Depot",
                     summary     => "Decouple object instantiation from usage.",
                   },
                   {
                     description => "Distribution OpenAPI-Render first released by MERKYS at 2020-01-31T10:56:36Z.",
                     module      => "OpenAPI::Render",
                     summary     => "Render OpenAPI specifications as documents",
                   },
                   {
                     description => "Distribution OpenTracing-AutoScope first released by VANHOESEL at 2020-01-16T14:24:42Z.",
                     module      => "OpenTracing::AutoScope",
                     summary     => "Automagically create and close scoped spans.",
                   },
                   {
                     description => "Distribution OpenTracing-Implementation first released by VANHOESEL at 2020-01-08T15:02:09Z.",
                     module      => "OpenTracing::Implementation",
                     summary     => "Use OpenTracing with a specific implementation",
                   },
                   {
                     description => "Distribution OpenTracing-Implementation-DataDog first released by VANHOESEL at 2020-01-15T20:12:38Z.",
                     module      => "OpenTracing::Implementation::DataDog",
                     summary     => "Sending traces to DataDog using Agent",
                   },
                   {
                     description => "Distribution OpenTracing-Implementation-NoOp first released by VANHOESEL at 2020-01-10T15:41:16Z.",
                     module      => "OpenTracing::Implementation::NoOp",
                     summary     => "Stops Crashing, doing nothing else",
                   },
                   {
                     description => "Distribution OpenTracing-Role first released by VANHOESEL at 2020-01-14T14:16:07Z.",
                     module      => "OpenTracing::Role",
                     summary     => "common attributes and methods for OpenTracing",
                   },
                   {
                     description => "Distribution Otogiri-Plugin-SelectWithColumns first released by YTURTLE at 2020-01-16T11:26:10Z.",
                     module      => "Otogiri::Plugin::SelectWithColumns",
                     summary     => "Otogiri plugin to search row-data that contains only specific columns from database",
                   },
                   {
                     description => "Distribution PERLANCAR-Foo-Bar first released by PERLANCAR at 2020-01-03T00:28:57Z.",
                     module      => "PERLANCAR::Foo::Bar",
                     summary     => "Foo, Bar, Foo::Bar, etc modules for testing",
                   },
                   {
                     description => "Distribution Pegex-TOML first released by INGY at 2020-01-16T06:07:13Z.",
                     module      => "Pegex::TOML",
                     summary     => "Pegex Loader for TOML",
                   },
                   {
                     description => "Distribution Perinci-CmdLine-Lite-Patch-ShowArgsAfterValidation first released by PERLANCAR at 2020-01-01T22:26:03Z.",
                     module      => "Perinci::CmdLine::Lite::Patch::ShowArgsAfterValidation",
                     summary     => "Patch Perinci::CmdLine::Lite's hook_before_action() to show arguments after validation",
                   },
                   {
                     description => "Distribution Qiime2-Artifact first released by PROCH at 2020-01-23T15:16:12Z.",
                     module      => "Qiime2::Artifact",
                     summary     => "A parser for Qiime2 artifact files",
                   },
                   {
                     description => "Distribution Qiime2-Reader first released by PROCH at 2020-01-23T14:28:28Z.",
                     module      => "Qiime2::Reader",
                     summary     => "A parser for Qiime2 artifact files",
                   },
                   {
                     description => "Distribution RT-Extension-DisableOtherTransaction first released by MITHR at 2020-01-24T15:06:17Z.",
                     module      => "RT::Extension::DisableOtherTransaction",
                     summary     => "RT-Extension-DisableOtherTransaction Extension",
                   },
                   {
                     description => "Distribution Regexp-Pattern-Path first released by PERLANCAR at 2020-01-01T22:26:37Z.",
                     module      => "Regexp::Pattern::Path",
                     summary     => "Regexp patterns related to path",
                   },
                   {
                     description => "Distribution Regexp-Pattern-Test-re_engine first released by PERLANCAR at 2020-01-04T05:39:49Z.",
                     module      => "Regexp::Pattern::Test::re_engine",
                     summary     => "Regexp patterns to test loading under re::engine::*",
                   },
                   {
                     description => "Distribution Require-Hook-More first released by PERLANCAR at 2020-01-04T05:31:55Z.",
                     module      => "Require::Hook::More",
                     summary     => "Load module like perl, with more options",
                   },
                   {
                     description => "Distribution Sah-Schemas-RegexpPattern first released by PERLANCAR at 2020-01-03T08:59:01Z.",
                     module      => "Sah::Schemas::RegexpPattern",
                     summary     => "Sah schemas related to Regexp::Pattern",
                   },
                   {
                     description => "Distribution Shout first released by NIKOLAS at 2020-01-23T19:15:18Z.",
                     module      => "Shout",
                     summary     => "Perl glue for libshout MP3 streaming source library",
                   },
                   {
                     description => "Distribution Sub-HandlesVia first released by TOBYINK at 2020-01-21T12:20:29Z.",
                     module      => "Sub::HandlesVia",
                     summary     => "alternative handles_via implementation",
                   },
                   {
                     description => "Distribution Sub-MultiMethod first released by TOBYINK at 2020-01-28T12:59:32Z.",
                     module      => "Sub::MultiMethod",
                     summary     => "yet another implementation of multimethods",
                   },
                   {
                     description => "Distribution TOML-Tiny first released by JEFFOBER at 2020-01-17T19:29:54Z.",
                     module      => "TOML::Tiny",
                     summary     => "a minimal, pure perl TOML parser and serializer",
                   },
                   {
                     description => "Distribution Term-Clear first released by DMUEY at 2020-01-21T15:39:57Z.",
                     module      => "Term::Clear",
                     summary     => "`clear` the terminal via a perl function",
                   },
                   {
                     description => "Distribution Test-Interface first released by VANHOESEL at 2020-01-28T16:29:58Z.",
                     module      => "Test::Interface",
                     summary     => "Test if a class implements an interface",
                   },
                   {
                     description => "Distribution Test-ProveDeps first released by PERLANCAR at 2020-01-29T08:50:57Z.",
                     module      => "Test::ProveDeps",
                     summary     => "Test using App::ProveDeps",
                   },
                   {
                     description => "Distribution Test-ProveRdeps first released by PERLANCAR at 2020-01-30T11:15:50Z.",
                     module      => "Test::ProveRdeps",
                     summary     => "Test using App::ProveRdeps",
                   },
                   {
                     description => "Distribution Test-SQLite first released by GENE at 2020-01-12T21:57:40Z.",
                     module      => "Test::SQLite",
                     summary     => "SQLite setup/teardown for tests",
                   },
                   {
                     description => "Distribution Tickit-App-Plugin-EscapePrefix first released by PEVANS at 2020-01-27T22:18:25Z.",
                     module      => "Tickit::App::Plugin::EscapePrefix",
                     summary     => "Tickit application plugin for Escape-prefixed shortcut keys",
                   },
                   {
                     description => "Distribution WebService-AbuseIPDB first released by HOUSTON at 2020-01-22T15:52:16Z.",
                     module      => "WebService::AbuseIPDB",
                     summary     => "Client for the API (version 2) of AbuseIPDB ",
                   },
                   {
                     description => "Distribution WebService-Pornhub first released by YUSUKEBE at 2020-01-19T22:24:05Z.",
                     module      => "WebService::Pornhub",
                     summary     => "Perl interface to the Pornhub.com API.",
                   },
                   {
                     description => "Distribution XS-boost-mini first released by SYBER at 2020-01-30T13:07:27Z.",
                     module      => "XS::boost::mini",
                     summary     => "C++ Boost library for XS.",
                   },
                   {
                     description => "Distribution XS-catch first released by SYBER at 2020-01-30T13:22:55Z.",
                     module      => "XS::catch",
                     summary     => "Catch test library for XS ",
                   },
                   {
                     description => "Distribution XS-libboost-mini first released by SYBER at 2020-01-30T15:51:05Z.",
                     module      => "XS::libboost::mini",
                     summary     => "C++ Boost library for XS (most common subset).",
                   },
                   {
                     description => "Distribution XS-libbrotli first released by DMOL at 2020-01-31T17:11:01Z.",
                     module      => "XS::libbrotli",
                     summary     => "Brotli compression library for XS.",
                   },
                   {
                     description => "Distribution XS-libcares first released by SYBER at 2020-01-31T12:21:26Z.",
                     module      => "XS::libcares",
                     summary     => "c-ares C library for XS.",
                   },
                   {
                     description => "Distribution XS-libcatch first released by SYBER at 2020-01-30T15:57:44Z.",
                     module      => "XS::libcatch",
                     summary     => "Catch test library for XS ",
                   },
                   {
                     description => "Distribution XS-libdwarf first released by DMOL at 2020-01-31T17:34:09Z.",
                     module      => "XS::libdwarf",
                     summary     => "DWARF debugging information for XS modules",
                   },
                   {
                     description => "Distribution XS-libgeos first released by SYBER at 2020-01-31T12:59:53Z.",
                     module      => "XS::libgeos",
                     summary     => "geos C++ library for XS ",
                   },
                   {
                     description => "Distribution XS-libpanda first released by SYBER at 2020-01-30T17:17:30Z.",
                     module      => "XS::libpanda",
                     summary     => "panda::lib C++ library for XS.",
                   },
                   {
                     description => "Distribution XS-libuv first released by SYBER at 2020-01-31T12:09:28Z.",
                     module      => "XS::libuv",
                     summary     => "libuv shared library for XS.",
                   },
                   {
                     description => "Distribution file first released by BOBK at 2020-01-07T18:52:54Z.",
                     module      => "file",
                     summary     => "Perl module to load files at compile-time, without BEGIN blocks.",
                   },
                   {
                     description => "Distribution filename first released by BOBK at 2020-01-07T21:30:51Z.",
                     module      => "filename",
                     summary     => "Perl module to load files at compile-time, without BEGIN blocks.",
                   },
                 ],
  summary     => "List of new distributions in Jan 2020",
};

1;
# ABSTRACT: List of new distributions in Jan 2020

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::NewDistributions::202001 - List of new distributions in Jan 2020

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::NewDistributions::202001 (from Perl distribution Acme-CPANModules-NewDistributions-202001), released on 2020-02-06.

=head1 DESCRIPTION

List of new distributions in Jan 2020.

Stats:

Number of new CPAN distributions this period: B<105>

Number of authors releasing new CPAN distributions this period: B<48>

Authors by number of new CPAN distributions this period:

 +----+-----------+---------------+
 | No | Author    | Distributions |
 +----+-----------+---------------+
 | 1  | PERLANCAR | 19            |
 | 1  | SYBER     | 14            |
 | 1  | VANHOESEL | 9             |
 | 1  | TOBYINK   | 4             |
 | 1  | DMOL      | 4             |
 | 1  | LTM       | 3             |
 | 1  | BOKUTIN   | 3             |
 | 1  | CDRAKE    | 2             |
 | 1  | MERKYS    | 2             |
 | 1  | BLUEFEET  | 2             |
 | 1  | BDFOY     | 2             |
 | 1  | BOBK      | 2             |
 | 1  | PROCH     | 2             |
 | 1  | SRCHULO   | 2             |
 | 1  | VRAG      | 2             |
 | 1  | NIKOLAS   | 1             |
 | 1  | DMUEY     | 1             |
 | 1  | NQOUNET   | 1             |
 | 1  | GENE      | 1             |
 | 1  | HACKTOR   | 1             |
 | 1  | HOUSTON   | 1             |
 | 1  | VADIML    | 1             |
 | 1  | GDT       | 1             |
 | 1  | WBRASWELL | 1             |
 | 1  | PIETRO    | 1             |
 | 1  | AFAN      | 1             |
 | 1  | YUSUKEBE  | 1             |
 | 1  | HMBRAND   | 1             |
 | 1  | YTURTLE   | 1             |
 | 1  | SKIM      | 1             |
 | 1  | DRAXIL    | 1             |
 | 1  | ROBFARR   | 1             |
 | 1  | JHTHORSEN | 1             |
 | 1  | NHORNE    | 1             |
 | 1  | PEVANS    | 1             |
 | 1  | CXW       | 1             |
 | 1  | BAYASHI   | 1             |
 | 1  | RAJ       | 1             |
 | 1  | SGRAY     | 1             |
 | 1  | JLCOOPER  | 1             |
 | 1  | PINGAN    | 1             |
 | 1  | JV        | 1             |
 | 1  | INGY      | 1             |
 | 1  | MITHR     | 1             |
 | 1  | JEFFOBER  | 1             |
 | 1  | SISYPHUS  | 1             |
 | 1  | GWILLIAMS | 1             |
 | 1  | RVOSA     | 1             |
 +----+-----------+---------------+

=head1 INCLUDED MODULES

=over

=item * L<Acme::CPANModules::OneAndTwoDecimalDigitsVersionTrap> - Chronicles CPAN distributions which have been trapped by the one- and two decimal digits versioning scheme

Distribution Acme-CPANModules-OneAndTwoDecimalDigitsVersionTrap first released by PERLANCAR at 2020-01-02T11:37:54Z.


=item * L<Alien::boost::mini> - C++ Boost library (no perl interface).

Distribution Alien-boost-mini first released by SYBER at 2020-01-25T14:45:26Z.


=item * L<Alien::cares> - c-ares C library (alien, without perl-adapters).

Distribution Alien-cares first released by SYBER at 2020-01-25T15:30:14Z.


=item * L<Alien::catch> - Catch test library http://catch-lib.net

Distribution Alien-catch first released by SYBER at 2020-01-24T15:25:30Z.


=item * L<Alien::libdwarf> - DWARF debugging information

Distribution Alien-libdwarf first released by DMOL at 2020-01-25T08:52:26Z.


=item * L<Alien::libgeos> - geos C++ library (alien, without perl-adapters).

Distribution Alien-libgeos first released by DMOL at 2020-01-25T09:57:02Z.


=item * L<Alien::libpanda> - panda::lib C++ library (alien).

Distribution Alien-libpanda first released by SYBER at 2020-01-24T16:14:02Z.


=item * L<Alien::uv> - libuv shared library (alien, without perl-adapters).

Distribution Alien-uv first released by SYBER at 2020-01-25T14:58:23Z.


=item * L<App::ProveRdeps> - Prove all distributions depending on specified module(s)

Distribution App-ProveRdeps first released by PERLANCAR at 2020-01-30T10:56:35Z.


=item * L<App::Unicode::Block> - Distribution for unicode-block script.

Distribution App-Unicode-Block first released by SKIM at 2020-01-19T16:51:51Z.


=item * L<App::geoip> - Show geological data based on hostname or IP address(es)

Distribution App-geoip first released by HMBRAND at 2020-01-16T13:50:05Z.


=item * L<App::lcpan::CmdBundle::similar_authors> - More lcpan subcommands related to finding similar authors

Distribution App-lcpan-CmdBundle-similar_authors first released by PERLANCAR at 2020-01-11T00:05:10Z.


=item * L<App::unbelievable> - Yet another site generator (can you believe it?)

Distribution App-unbelievable first released by CXW at 2020-01-27T02:49:06Z.


=item * L<App::url> - format a URL according to a sprintf-like template

Distribution App-url first released by BDFOY at 2020-01-03T04:10:44Z.


=item * L<AtteanX::Parser::JSONLD> - JSONLD Parser

Distribution AtteanX-Parser-JSONLD first released by GWILLIAMS at 2020-01-22T18:23:23Z.


=item * L<Bencher::Scenario::strftimeq> - Benchmark strftimeq() routines

Distribution Bencher-Scenario-strftimeq first released by PERLANCAR at 2020-01-26T00:05:03Z.


=item * L<Bencher::Scenarios::ModuleInstalledTiny> - Scenarios to benchmark Module::Installed::Tiny

Distribution Bencher-Scenarios-ModuleInstalledTiny first released by PERLANCAR at 2020-01-13T01:01:35Z.


=item * L<BettingStrategy::MonteCarlo> - Monte Carlo method for gambling.

Distribution BettingStrategy-MonteCarlo first released by NQOUNET at 2020-01-16T18:55:33Z.


=item * L<Bio::WGS2NCBI> - module to assist in submitting whole genome sequencing projects to NCBI

Distribution Bio-WGS2NCBI first released by RVOSA at 2020-01-23T15:54:29Z.


=item * L<CGI::Application::Plugin::OpenTracing> - Use OpenTracing in CGI Applications

Distribution CGI-Application-Plugin-OpenTracing first released by VANHOESEL at 2020-01-16T13:57:56Z.


=item * L<Calendar::Dates::UnitedNations::InternationalDays> - United Nations' International Days

Distribution Calendar-Dates-UnitedNations-InternationalDays first released by PERLANCAR at 2020-01-01T11:35:05Z.


=item * L<Catalyst::Authentication::Credential::RedmineCookie> - Decode the redmine cookie _redmine_session

Distribution Catalyst-Authentication-Credential-RedmineCookie first released by BOKUTIN at 2020-01-09T06:00:28Z.


=item * L<Catalyst::Authentication::RedmineCookie> - Decode the redmine cookie _redmine_session

Distribution Catalyst-Authentication-RedmineCookie first released by BOKUTIN at 2020-01-17T07:22:36Z.


=item * L<Chart::Colors> - Perl extension to return an endless stream of new distinct RGB colours codes (good for coloring any number of chart lines)

Distribution Chart-Colors first released by CDRAKE at 2020-01-20T10:56:51Z.


=item * L<Config::Registry> - Settings bundler.

Distribution Config-Registry first released by BLUEFEET at 2020-01-19T15:54:32Z.


=item * L<Crypto::NanoRPC> - Perl module for interacting with Nano node

Distribution Crypto-NanoRPC first released by HACKTOR at 2020-01-16T15:17:14Z.


=item * L<Data::Validate::Chemistry> - Validate common chemical identifiers

Distribution Data-Validate-Chemistry first released by MERKYS at 2020-01-29T14:38:32Z.


=item * L<Date::strftimeq> - POSIX::strftime() with support for embedded perl code in %(...)q

Distribution Date-strftimeq first released by PERLANCAR at 2020-01-19T01:57:48Z.


=item * L<DateTime::Format::Strftimeq> - Format DateTime object using DateTimeX::strftimeq

Distribution DateTime-Format-Strftimeq first released by PERLANCAR at 2020-01-12T00:05:08Z.


=item * L<DateTimeX::strftimeq> - POSIX::strftime() with support for embedded perl code in %(...)q

Distribution DateTimeX-strftimeq first released by PERLANCAR at 2020-01-05T00:05:58Z.


=item * L<Dist::Zilla::Plugin::Test::ProveDeps> - Add release test to run 'prove' on dependent distributions

Distribution Dist-Zilla-Plugin-Test-ProveDeps first released by PERLANCAR at 2020-01-29T09:03:54Z.


=item * L<Dist::Zilla::Plugin::Test::ProveRdeps> - Add release test to run 'prove' on distributions that depend on us

Distribution Dist-Zilla-Plugin-Test-ProveRdeps first released by PERLANCAR at 2020-01-30T11:45:24Z.


=item * L<Duadua> - Detect User-Agent

Distribution Duadua first released by BAYASHI at 2020-01-31T05:07:25Z.


=item * L<Eircode> - Validation and utilities for Eircodes / Irish postcodes

Distribution Eircode first released by DRAXIL at 2020-01-20T11:11:18Z.


=item * L<FTN::Crypt> - Encryption of the FTN messages.

Distribution FTN-Crypt first released by PIETRO at 2020-01-15T20:49:51Z.


=item * L<File::BackupCopy> - create a backup copy of the file.

Distribution File-BackupCopy first released by SGRAY at 2020-01-20T07:48:10Z.


=item * L<Font::Fontconfig> - An Object Oriented interface to fontconfig

Distribution Font-Fontconfig first released by VANHOESEL at 2020-01-20T16:38:30Z.


=item * L<Font::Selector> - select the right font for rendering

Distribution Font-Selector first released by VANHOESEL at 2020-01-21T08:20:21Z.


=item * L<Geo::Coder::DAMS> - Perl bindings for Japanese Geocoder DAMS

Distribution Geo-Coder-DAMS first released by BOKUTIN at 2020-01-04T19:00:11Z.


=item * L<HarfBuzz::Shaper> - Use HarfBuzz for text shaping

Distribution HarfBuzz-Shaper first released by JV at 2020-01-25T20:50:26Z.


=item * L<Huawei::Info::Ipaddr>

Distribution Huawei-Info-Ipaddr first released by PINGAN at 2020-01-08T15:01:58Z.


=item * L<IO::EPP> - Object and procedure interface of the client-side for work with EPP API of registries and some resellers

Distribution IO-EPP first released by VADIML at 2020-01-12T12:01:15Z.


=item * L<IP::Decimal> - Convert IP to Decimal and Decimal to IP

Distribution IP-Decimal first released by LTM at 2020-01-21T07:46:48Z.


=item * L<JS::AA> - Encode and Decode AA

Distribution JS-AA first released by LTM at 2020-01-24T00:59:33Z.


=item * L<JS::JJ> - Encode and Decode JJ

Distribution JS-JJ first released by LTM at 2020-01-30T02:22:54Z.


=item * L<Lingua::FR::Numbers::Ordinate> - go from cardinal number (3) to ordinal ("3e")

Distribution Lingua-FR-Numbers-Ordinate first released by NHORNE at 2020-01-03T03:04:16Z.


=item * L<List::Uniqnum> - a rendition of List::Util::uniqnum minus the bugs.

Distribution List-Uniqnum first released by SISYPHUS at 2020-01-27T11:35:40Z.


=item * L<Loctools::Net> - Shared network-related modules

Distribution Loctools-Net first released by AFAN at 2020-01-15T21:38:52Z.


=item * L<MLPerl> - Machine Learning Algorithms & Applications in Perl

Distribution MLPerl first released by WBRASWELL at 2020-01-02T05:38:40Z.


=item * L<Math::StdDev> - Pure-perl mean and variance computation supporting running/online calculation (Welford's algorithm)

Distribution Math-StdDev first released by CDRAKE at 2020-01-20T09:50:44Z.


=item * L<Mojo::DB::Connector> - Create and cache DB connections using common connection info

Distribution Mojo-DB-Connector first released by SRCHULO at 2020-01-26T01:25:31Z.


=item * L<Mojo::DB::Results::Role::MoreMethods> - More methods for DB Results, like Mojo::Pg::Results and Mojo::mysql::Results

Distribution Mojo-DB-Results-Role-MoreMethods first released by SRCHULO at 2020-01-05T23:22:29Z.


=item * L<Mojolicious::Plugin::Iconify> - Iconify helpers.

Distribution Mojolicious-Plugin-Iconify first released by GDT at 2020-01-04T15:00:45Z.


=item * L<Mojolicious::Plugin::ServerType> - A Mojolicious Plugin that provides a helper that identifies the server type

Distribution Mojolicious-Plugin-ServerType first released by JLCOOPER at 2020-01-13T13:12:40Z.


=item * L<Mojolicious::Plugin::Systemd> - Configure your app from within systemd service file

Distribution Mojolicious-Plugin-Systemd first released by JHTHORSEN at 2020-01-09T00:02:48Z.


=item * L<MooX::Pression> - express yourself through moo

Distribution MooX-Pression first released by TOBYINK at 2020-01-16T00:50:32Z.


=item * L<MooseX::Function::Parameters>

Distribution MooseX-Function-Parameters first released by ROBFARR at 2020-01-03T19:49:47Z.


=item * L<Net::MyIP> - Get ip address from https://api.myip.com/

Distribution Net-MyIP first released by RAJ at 2020-01-24T10:48:45Z.


=item * L<Net::Prometheus::Pushgateway> - client module for pushing metrics to prometheus exporter (pushgateway, prometheus aggregation gateway)

Distribution Net-Prometheus-Pushgateway first released by VRAG at 2020-01-17T15:03:05Z.


=item * L<Net::PublicSuffixList> - The Mozilla Public Suffix List

Distribution Net-PublicSuffixList first released by BDFOY at 2020-01-08T03:56:52Z.


=item * L<Net::SockAddr> - Socket address OO-wrapper with Perl and C++ interface.

Distribution Net-SockAddr first released by SYBER at 2020-01-22T16:15:12Z.


=item * L<Net::SyslogNg> - client module for writing to syslog server (rfc5424)

Distribution Net-SyslogNg first released by VRAG at 2020-01-10T09:59:11Z.


=item * L<Object::Adhoc> - make objects without the hassle of defining a class first

Distribution Object-Adhoc first released by TOBYINK at 2020-01-24T17:12:36Z.


=item * L<Object::Depot> - Decouple object instantiation from usage.

Distribution Object-Depot first released by BLUEFEET at 2020-01-20T20:33:21Z.


=item * L<OpenAPI::Render> - Render OpenAPI specifications as documents

Distribution OpenAPI-Render first released by MERKYS at 2020-01-31T10:56:36Z.


=item * L<OpenTracing::AutoScope> - Automagically create and close scoped spans.

Distribution OpenTracing-AutoScope first released by VANHOESEL at 2020-01-16T14:24:42Z.


=item * L<OpenTracing::Implementation> - Use OpenTracing with a specific implementation

Distribution OpenTracing-Implementation first released by VANHOESEL at 2020-01-08T15:02:09Z.


=item * L<OpenTracing::Implementation::DataDog> - Sending traces to DataDog using Agent

Distribution OpenTracing-Implementation-DataDog first released by VANHOESEL at 2020-01-15T20:12:38Z.


=item * L<OpenTracing::Implementation::NoOp> - Stops Crashing, doing nothing else

Distribution OpenTracing-Implementation-NoOp first released by VANHOESEL at 2020-01-10T15:41:16Z.


=item * L<OpenTracing::Role> - common attributes and methods for OpenTracing

Distribution OpenTracing-Role first released by VANHOESEL at 2020-01-14T14:16:07Z.


=item * L<Otogiri::Plugin::SelectWithColumns> - Otogiri plugin to search row-data that contains only specific columns from database

Distribution Otogiri-Plugin-SelectWithColumns first released by YTURTLE at 2020-01-16T11:26:10Z.


=item * L<PERLANCAR::Foo::Bar> - Foo, Bar, Foo::Bar, etc modules for testing

Distribution PERLANCAR-Foo-Bar first released by PERLANCAR at 2020-01-03T00:28:57Z.


=item * L<Pegex::TOML> - Pegex Loader for TOML

Distribution Pegex-TOML first released by INGY at 2020-01-16T06:07:13Z.


=item * L<Perinci::CmdLine::Lite::Patch::ShowArgsAfterValidation> - Patch Perinci::CmdLine::Lite's hook_before_action() to show arguments after validation

Distribution Perinci-CmdLine-Lite-Patch-ShowArgsAfterValidation first released by PERLANCAR at 2020-01-01T22:26:03Z.


=item * L<Qiime2::Artifact> - A parser for Qiime2 artifact files

Distribution Qiime2-Artifact first released by PROCH at 2020-01-23T15:16:12Z.


=item * L<Qiime2::Reader> - A parser for Qiime2 artifact files

Distribution Qiime2-Reader first released by PROCH at 2020-01-23T14:28:28Z.


=item * L<RT::Extension::DisableOtherTransaction> - RT-Extension-DisableOtherTransaction Extension

Distribution RT-Extension-DisableOtherTransaction first released by MITHR at 2020-01-24T15:06:17Z.


=item * L<Regexp::Pattern::Path> - Regexp patterns related to path

Distribution Regexp-Pattern-Path first released by PERLANCAR at 2020-01-01T22:26:37Z.


=item * L<Regexp::Pattern::Test::re_engine> - Regexp patterns to test loading under re::engine::*

Distribution Regexp-Pattern-Test-re_engine first released by PERLANCAR at 2020-01-04T05:39:49Z.


=item * L<Require::Hook::More> - Load module like perl, with more options

Distribution Require-Hook-More first released by PERLANCAR at 2020-01-04T05:31:55Z.


=item * L<Sah::Schemas::RegexpPattern> - Sah schemas related to Regexp::Pattern

Distribution Sah-Schemas-RegexpPattern first released by PERLANCAR at 2020-01-03T08:59:01Z.


=item * L<Shout> - Perl glue for libshout MP3 streaming source library

Distribution Shout first released by NIKOLAS at 2020-01-23T19:15:18Z.


=item * L<Sub::HandlesVia> - alternative handles_via implementation

Distribution Sub-HandlesVia first released by TOBYINK at 2020-01-21T12:20:29Z.


=item * L<Sub::MultiMethod> - yet another implementation of multimethods

Distribution Sub-MultiMethod first released by TOBYINK at 2020-01-28T12:59:32Z.


=item * L<TOML::Tiny> - a minimal, pure perl TOML parser and serializer

Distribution TOML-Tiny first released by JEFFOBER at 2020-01-17T19:29:54Z.


=item * L<Term::Clear> - `clear` the terminal via a perl function

Distribution Term-Clear first released by DMUEY at 2020-01-21T15:39:57Z.


=item * L<Test::Interface> - Test if a class implements an interface

Distribution Test-Interface first released by VANHOESEL at 2020-01-28T16:29:58Z.


=item * L<Test::ProveDeps> - Test using App::ProveDeps

Distribution Test-ProveDeps first released by PERLANCAR at 2020-01-29T08:50:57Z.


=item * L<Test::ProveRdeps> - Test using App::ProveRdeps

Distribution Test-ProveRdeps first released by PERLANCAR at 2020-01-30T11:15:50Z.


=item * L<Test::SQLite> - SQLite setup/teardown for tests

Distribution Test-SQLite first released by GENE at 2020-01-12T21:57:40Z.


=item * L<Tickit::App::Plugin::EscapePrefix> - Tickit application plugin for Escape-prefixed shortcut keys

Distribution Tickit-App-Plugin-EscapePrefix first released by PEVANS at 2020-01-27T22:18:25Z.


=item * L<WebService::AbuseIPDB> - Client for the API (version 2) of AbuseIPDB 

Distribution WebService-AbuseIPDB first released by HOUSTON at 2020-01-22T15:52:16Z.


=item * L<WebService::Pornhub> - Perl interface to the Pornhub.com API.

Distribution WebService-Pornhub first released by YUSUKEBE at 2020-01-19T22:24:05Z.


=item * L<XS::boost::mini> - C++ Boost library for XS.

Distribution XS-boost-mini first released by SYBER at 2020-01-30T13:07:27Z.


=item * L<XS::catch> - Catch test library for XS 

Distribution XS-catch first released by SYBER at 2020-01-30T13:22:55Z.


=item * L<XS::libboost::mini> - C++ Boost library for XS (most common subset).

Distribution XS-libboost-mini first released by SYBER at 2020-01-30T15:51:05Z.


=item * L<XS::libbrotli> - Brotli compression library for XS.

Distribution XS-libbrotli first released by DMOL at 2020-01-31T17:11:01Z.


=item * L<XS::libcares> - c-ares C library for XS.

Distribution XS-libcares first released by SYBER at 2020-01-31T12:21:26Z.


=item * L<XS::libcatch> - Catch test library for XS 

Distribution XS-libcatch first released by SYBER at 2020-01-30T15:57:44Z.


=item * L<XS::libdwarf> - DWARF debugging information for XS modules

Distribution XS-libdwarf first released by DMOL at 2020-01-31T17:34:09Z.


=item * L<XS::libgeos> - geos C++ library for XS 

Distribution XS-libgeos first released by SYBER at 2020-01-31T12:59:53Z.


=item * L<XS::libpanda> - panda::lib C++ library for XS.

Distribution XS-libpanda first released by SYBER at 2020-01-30T17:17:30Z.


=item * L<XS::libuv> - libuv shared library for XS.

Distribution XS-libuv first released by SYBER at 2020-01-31T12:09:28Z.


=item * L<file> - Perl module to load files at compile-time, without BEGIN blocks.

Distribution file first released by BOBK at 2020-01-07T18:52:54Z.


=item * L<filename> - Perl module to load files at compile-time, without BEGIN blocks.

Distribution filename first released by BOBK at 2020-01-07T21:30:51Z.


=back

=head1 FAQ

=head2 What are ways to use this module?

Aside from reading it, you can install all the listed modules using
L<cpanmodules>:

    % cpanmodules ls-entries NewDistributions::202001 | cpanm -n

or L<Acme::CM::Get>:

    % perl -MAcme::CM::Get=NewDistributions::202001 -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n

This module also helps L<lcpan> produce a more meaningful result for C<lcpan
related-mods> when it comes to finding related modules for the modules listed
in this Acme::CPANModules module.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModules-NewDistributions-202001>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-NewDistributions-202001>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-NewDistributions-202001>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
